--
-- Selected TOC Entries:
--
--
-- Data for TOC Entry ID 1 (OID 1933100)
--
-- Name: protocol Type: TABLE DATA Owner: aliphe
--


INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('DBI','DBI connector','inout');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('FTP','FTP connectors','inout');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('HTTP','HTTP connector','incom');
-- INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('HTTPS','Secure HTTP connector','incom');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('LDAP','LDAP connector','inout');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('LFS','Local file system','inout');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('POP3','POP3 connector','inout');
-- INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('RPC','Remote Procedure Call','inout');
INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('SMTP','SMTP connector','outgo');
-- INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('SOAP','Simple Object Access Protocol','inout');
-- INSERT INTO "protocol" ("protocolid","protocollabel","inoutdir") VALUES ('XMLRPC','XML Based Remote Procedure Call','inout');
